User prompt
just take it back 2 steps back
User prompt
make the game phone screen ratio
User prompt
make the game 9:16
User prompt
add monsters a death effect.
User prompt
add sound effect like hit sound and death sound
User prompt
upgrade again
User prompt
upgrade the height of the bars
Code edit (10 edits merged)
Please save this source code
User prompt
add a normal health bar then
User prompt
remove all the health bars
User prompt
do the background size phone size
Code edit (1 edits merged)
Please save this source code
Code edit (4 edits merged)
Please save this source code
User prompt
remove the bar says 10/10
User prompt
remove health bar from top side and make it bigger the down side one. Do more attractive and good number text style
User prompt
Increase your health bar too
User prompt
Enlarge the monsters to fit the screen. Make it look nice on the eye
User prompt
use backgorund as a background
User prompt
change monster2,3,4,5 height to 600
User prompt
Change monster2,3,4,5, width to 400
Code edit (1 edits merged)
Please save this source code
User prompt
fix the problem
User prompt
it have to switch when a monster dies. Do not use any monster prefab just use monster1 monster2 monster3 monster4 monster5 in assets section.
User prompt
Use the monsters I call monsters in the Assets section and when each one dies, the other one takes its place.
User prompt
when i killed a monster it should be spawn different mosnter
/****
* Plugins
****/
var tween = LK.import("@upit/tween.v1");
/****
* Classes
****/
// Monster class
var Monster = Container.expand(function () {
var self = Container.call(this);
// Default monster uses 'monster' asset
var monsterBody = self.attachAsset('monster', {
anchorX: 0.5,
anchorY: 0.5
});
// Monster hit overlay (hidden by default)
var monsterHit = self.attachAsset('monsterHit', {
anchorX: 0.5,
anchorY: 0.5,
alpha: 0
});
// Health values
self.maxHealth = 10;
self.health = self.maxHealth;
// Hit animation
self.hitAnim = function () {
// Show hit overlay quickly, then fade out
monsterHit.alpha = 0.6;
tween(monsterHit, {
alpha: 0
}, {
duration: 180,
easing: tween.linear
});
// Slight scale pop
tween.stop(monsterBody, {
scaleX: true,
scaleY: true
});
monsterBody.scaleX = 1.1;
monsterBody.scaleY = 1.1;
tween(monsterBody, {
scaleX: 1,
scaleY: 1
}, {
duration: 120,
easing: tween.easeOut
});
};
// Take damage
self.takeDamage = function (amount) {
self.health -= amount;
if (self.health < 0) {
self.health = 0;
}
self.hitAnim();
if (self.health === 0) {
LK.getSound('death').play();
LK.effects.flashObject(monsterBody, 0xffffff, 400);
} else {
LK.getSound('hit').play();
}
};
// Reset monster health
self.resetHealth = function (newMax) {
self.maxHealth = newMax;
self.health = self.maxHealth;
};
// On tap/click
self.down = function (x, y, obj) {
self.takeDamage(1);
};
// Initialize health bar
return self;
});
// Monster2 class
var Monster2 = Container.expand(function () {
var self = Container.call(this);
var monsterBody = self.attachAsset('monster2', {
anchorX: 0.5,
anchorY: 0.5
});
var monsterHit = self.attachAsset('monster2', {
anchorX: 0.5,
anchorY: 0.5,
alpha: 0.3
});
self.maxHealth = 12;
self.health = self.maxHealth;
self.hitAnim = function () {
monsterHit.alpha = 0.7;
tween(monsterHit, {
alpha: 0.3
}, {
duration: 180,
easing: tween.linear
});
tween.stop(monsterBody, {
scaleX: true,
scaleY: true
});
monsterBody.scaleX = 1.15;
monsterBody.scaleY = 1.15;
tween(monsterBody, {
scaleX: 1,
scaleY: 1
}, {
duration: 120,
easing: tween.easeOut
});
};
self.takeDamage = function (amount) {
self.health -= amount;
if (self.health < 0) {
self.health = 0;
}
self.hitAnim();
if (self.health === 0) {
LK.getSound('death').play();
LK.effects.flashObject(monsterBody, 0xffffff, 400);
} else {
LK.getSound('hit').play();
}
};
self.resetHealth = function (newMax) {
self.maxHealth = newMax;
self.health = self.maxHealth;
};
self.down = function (x, y, obj) {
self.takeDamage(1);
};
return self;
});
// Monster3 class
var Monster3 = Container.expand(function () {
var self = Container.call(this);
var monsterBody = self.attachAsset('monster3', {
anchorX: 0.5,
anchorY: 0.5
});
var monsterHit = self.attachAsset('monster3', {
anchorX: 0.5,
anchorY: 0.5,
alpha: 0.3
});
self.maxHealth = 15;
self.health = self.maxHealth;
self.hitAnim = function () {
monsterHit.alpha = 0.7;
tween(monsterHit, {
alpha: 0.3
}, {
duration: 180,
easing: tween.linear
});
tween.stop(monsterBody, {
scaleX: true,
scaleY: true
});
monsterBody.scaleX = 1.2;
monsterBody.scaleY = 1.2;
tween(monsterBody, {
scaleX: 1,
scaleY: 1
}, {
duration: 120,
easing: tween.easeOut
});
};
self.takeDamage = function (amount) {
self.health -= amount;
if (self.health < 0) {
self.health = 0;
}
self.hitAnim();
if (self.health === 0) {
LK.getSound('death').play();
LK.effects.flashObject(monsterBody, 0xffffff, 400);
} else {
LK.getSound('hit').play();
}
};
self.resetHealth = function (newMax) {
self.maxHealth = newMax;
self.health = self.maxHealth;
};
self.down = function (x, y, obj) {
self.takeDamage(1);
};
return self;
});
// Monster4 class
var Monster4 = Container.expand(function () {
var self = Container.call(this);
var monsterBody = self.attachAsset('monster4', {
anchorX: 0.5,
anchorY: 0.5
});
var monsterHit = self.attachAsset('monster4', {
anchorX: 0.5,
anchorY: 0.5,
alpha: 0.3
});
self.maxHealth = 18;
self.health = self.maxHealth;
self.hitAnim = function () {
monsterHit.alpha = 0.7;
tween(monsterHit, {
alpha: 0.3
}, {
duration: 180,
easing: tween.linear
});
tween.stop(monsterBody, {
scaleX: true,
scaleY: true
});
monsterBody.scaleX = 1.25;
monsterBody.scaleY = 1.25;
tween(monsterBody, {
scaleX: 1,
scaleY: 1
}, {
duration: 120,
easing: tween.easeOut
});
};
self.takeDamage = function (amount) {
self.health -= amount;
if (self.health < 0) {
self.health = 0;
}
self.hitAnim();
if (self.health === 0) {
LK.getSound('death').play();
LK.effects.flashObject(monsterBody, 0xffffff, 400);
} else {
LK.getSound('hit').play();
}
};
self.resetHealth = function (newMax) {
self.maxHealth = newMax;
self.health = self.maxHealth;
};
self.down = function (x, y, obj) {
self.takeDamage(1);
};
return self;
});
// Monster5 class (using 'monster5' asset)
var Monster5 = Container.expand(function () {
var self = Container.call(this);
var monsterBody = self.attachAsset('monster5', {
anchorX: 0.5,
anchorY: 0.5
});
var monsterHit = self.attachAsset('monster5', {
anchorX: 0.5,
anchorY: 0.5,
alpha: 0.3
});
self.maxHealth = 20;
self.health = self.maxHealth;
self.hitAnim = function () {
monsterHit.alpha = 0.7;
tween(monsterHit, {
alpha: 0.3
}, {
duration: 180,
easing: tween.linear
});
tween.stop(monsterBody, {
scaleX: true,
scaleY: true
});
monsterBody.scaleX = 1.3;
monsterBody.scaleY = 1.3;
tween(monsterBody, {
scaleX: 1,
scaleY: 1
}, {
duration: 120,
easing: tween.easeOut
});
};
self.takeDamage = function (amount) {
self.health -= amount;
if (self.health < 0) {
self.health = 0;
}
self.hitAnim();
if (self.health === 0) {
LK.getSound('death').play();
LK.effects.flashObject(monsterBody, 0xffffff, 400);
} else {
LK.getSound('hit').play();
}
};
self.resetHealth = function (newMax) {
self.maxHealth = newMax;
self.health = self.maxHealth;
};
self.down = function (x, y, obj) {
self.takeDamage(1);
};
return self;
});
/****
* Initialize Game
****/
// MonsterFactory to spawn a random monster type
var game = new LK.Game({
backgroundColor: 0x181818
});
/****
* Game Code
****/
// Keep track of last monster type index
// MonsterFactory to spawn a random monster type
var lastMonsterIdx = -1;
function MonsterFactory() {
// List of monster constructors, one for each asset
// We'll define Monster5 inline below
var monsterTypes = [Monster, Monster2, Monster3, Monster4, Monster5];
var idx;
// Pick a random type different from last
if (monsterTypes.length > 1) {
do {
idx = Math.floor(Math.random() * monsterTypes.length);
} while (idx === lastMonsterIdx);
} else {
idx = 0;
}
lastMonsterIdx = idx;
return new monsterTypes[idx]();
}
var score = 0;
// Score text
var scoreTxt = new Text2('0', {
size: 120,
fill: "#fff"
});
scoreTxt.anchor.set(0.5, 0);
// Place at top center, but not in top 100px (avoid menu)
scoreTxt.y = 20;
scoreTxt.x = 1080 / 2;
LK.gui.top.addChild(scoreTxt);
// Add background image as a background layer, scaled to always fill the phone screen (game area 1080x2340 for 9:19.5)
var background = LK.getAsset('background', {
anchorX: 0.5,
anchorY: 0.5,
x: 1080 / 2,
y: 2340 / 2,
width: 1080,
height: 2340
});
game.addChild(background, 0); // Add at index 0 to ensure it's behind everything
// Center position for monster (adjusted for large monster size)
var centerX = 1080 / 2;
var centerY = 2340 / 2 + 60;
// Current monster
var monster = null;
// Function to spawn a new monster
function spawnMonster() {
// Remove old monster if exists
if (monster) {
monster.destroy();
monster = null;
}
// Remove old health bar if exists
if (game.monsterHealthBarBg) {
game.monsterHealthBarBg.destroy();
game.monsterHealthBarBg = null;
}
if (game.monsterHealthBarFg) {
game.monsterHealthBarFg.destroy();
game.monsterHealthBarFg = null;
}
// Increase difficulty: every 10 monsters, +2 health
var baseHealth = 10 + Math.floor(score / 10) * 2;
// Use MonsterFactory to get a random monster type
monster = MonsterFactory();
monster.x = centerX;
monster.y = centerY;
// Set health scaling for all monsters
if (typeof monster.resetHealth === "function") {
monster.resetHealth(baseHealth);
}
game.addChild(monster);
// Add health bar background and foreground above monster
var barWidth = 540;
var barHeight = 160; // Adjusted for phone screen ratio
var barOffsetY = -monster.height / 2 - 80; // Adjusted offset for new aspect
// Health bar background
var healthBarBg = LK.getAsset('healthBarBg', {
anchorX: 0.5,
anchorY: 0.5,
width: barWidth,
height: barHeight,
x: monster.x,
y: monster.y + barOffsetY
});
game.addChild(healthBarBg);
// Health bar foreground
var healthBarFg = LK.getAsset('healthBarFg', {
anchorX: 0.5,
anchorY: 0.5,
width: barWidth - 16,
height: barHeight - 32,
// Increased height, but slightly less than background for border effect
x: monster.x,
y: monster.y + barOffsetY
});
game.addChild(healthBarFg);
// Store for update/removal
game.monsterHealthBarBg = healthBarBg;
game.monsterHealthBarFg = healthBarFg;
// Attach update function to monster for health bar
monster.updateHealthBar = function () {
// Update bar position to follow monster
healthBarBg.x = monster.x;
healthBarBg.y = monster.y + barOffsetY;
healthBarFg.x = monster.x;
healthBarFg.y = monster.y + barOffsetY;
// Update bar width to reflect health
var pct = Math.max(0, monster.health / monster.maxHealth);
healthBarFg.width = (barWidth - 16) * pct;
};
}
// Game update loop
game.update = function () {
if (!monster) {
return;
}
// If monster is dead, increment score and spawn new
if (monster.health <= 0) {
score += 1;
scoreTxt.setText(score);
spawnMonster();
} else if (monster && typeof monster.updateHealthBar === "function") {
monster.updateHealthBar();
}
};
// Start first monster
spawnMonster(); ===================================================================
--- original.js
+++ change.js
@@ -345,23 +345,23 @@
});
scoreTxt.anchor.set(0.5, 0);
// Place at top center, but not in top 100px (avoid menu)
scoreTxt.y = 20;
-scoreTxt.x = 1152 / 2;
+scoreTxt.x = 1080 / 2;
LK.gui.top.addChild(scoreTxt);
// Add background image as a background layer, scaled to always fill the phone screen (game area 1152x2048 for 9:16)
var background = LK.getAsset('background', {
anchorX: 0.5,
anchorY: 0.5,
- x: 1152 / 2,
- y: 2048 / 2,
- width: 1152,
- height: 2048
+ x: 1080 / 2,
+ y: 2340 / 2,
+ width: 1080,
+ height: 2340
});
game.addChild(background, 0); // Add at index 0 to ensure it's behind everything
// Center position for monster (adjusted for large monster size)
-var centerX = 1152 / 2;
-var centerY = 2048 / 2 + 60;
+var centerX = 1080 / 2;
+var centerY = 2340 / 2 + 60;
// Current monster
var monster = null;
// Function to spawn a new monster
function spawnMonster() {
@@ -390,11 +390,11 @@
monster.resetHealth(baseHealth);
}
game.addChild(monster);
// Add health bar background and foreground above monster
- var barWidth = 500;
- var barHeight = 140; // Adjusted for 9:16
- var barOffsetY = -monster.height / 2 - 60; // Adjusted offset for new aspect
+ var barWidth = 540;
+ var barHeight = 160; // Adjusted for phone screen ratio
+ var barOffsetY = -monster.height / 2 - 80; // Adjusted offset for new aspect
// Health bar background
var healthBarBg = LK.getAsset('healthBarBg', {
anchorX: 0.5,
@@ -345,23 +345,23 @@
LK.gui.top.addChild(scoreTxt);
-// Add background image as a background layer, scaled to always fill the phone screen (game area 1152x2048 for 9:16)
+// Add background image as a background layer, scaled to always fill the phone screen (game area 1080x2340 for 9:19.5)
var background = LK.getAsset('background', {
anchorX: 0.5,
anchorY: 0.5,